@@ -86,7 +86,10 @@ class Users(_defaults_.Defaults):
 		self.__timestamps__ = Dictionary({})
 		self.__api_keys__ = Dictionary({})
 		self.__subscriptions__ = Dictionary({})
-		self.__verification_codes__ = Dictionary(path=self.db.join("data/verification_codes"), default={}, load=self.live)
+		if self.live:
+			self.__verification_codes__ = Dictionary(path=self.db.join("data/verification_codes"), default={}, load=self.live)
+		else:
+			self.__verification_codes__ = Dictionary(path=self.db.join("data/verification_codes"))
 
 		#
 	def get(self, 
@@ -1116,6 +1119,12 @@ class Users(_defaults_.Defaults):
 
 		#
 	def __get_path__(self, email=None, username=None, create=False):
+		if email == None and "@" in username: 
+			email = username 
+			username = None
+		if username == None and "@" not in email: 
+			username = email
+			email = None
 		if self.id_by_username:
 			if username == None and email != None:
 				response = self.get(email=email)
@@ -1123,6 +1132,7 @@ class Users(_defaults_.Defaults):
 				username = response.user.username
 			id = username
 			if "@" in username:
+
 				raise ValueError(f"Forbidden @ character found in username: [{username}].")
 		else:
 			if email == None and username != None:
